@@ -21,7 +21,7 @@ use MIME::Lite::TT;
 use MIME::Lite::TT::HTML;
 use Params::Validate qw( :all );
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -135,16 +135,16 @@ From source:
   $ tar xfz Apache2-WebApp-Plugin-Mail-0.X.X.tar.gz
   $ perl MakeFile.PL PREFIX=~/path/to/custom/dir LIB=~/path/to/custom/lib
   $ make
-  $ make test     <--- Make sure you do this before contacting me
+  $ make test
   $ make install
 
 Perl one liner using CPAN.pm:
 
-  perl -MCPAN -e 'install Apache2::WebApp::Plugin::Mail'
+  $ perl -MCPAN -e 'install Apache2::WebApp::Plugin::Mail'
 
 Use of CPAN.pm in interactive mode:
 
-  $> perl -MCPAN -e shell
+  $ perl -MCPAN -e shell
   cpan> install Apache2::WebApp::Plugin::Mail
   cpan> quit
 
